==> pandoc-citeproc-0.11.1.3-1-i686.pkg.tar.xz: usr/share/haskell/register/pandoc-citeproc.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/sbin:/usr/bin:/sbin:/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: pandoc-citeproc
version: 0.11.1.3
id: pandoc-citeproc-0.11.1.3-ILikW0TUk5qIp9f2RvCVVS
key: pandoc-citeproc-0.11.1.3-ILikW0TUk5qIp9f2RvCVVS
license: BSD3
maintainer: jgm@berkeley.edu
homepage: https://github.com/jgm/pandoc-citeproc
synopsis: Supports using pandoc with citeproc
description:
    The pandoc-citeproc library exports functions for
    using the citeproc system with pandoc.  It relies on
    citeproc-hs, a library for rendering
    bibliographic reference citations into a variety
    of styles using a macro language called Citation
    Style Language (CSL). More details on CSL can be
    found here: <http://citationstyles.org/>.
    .
    Currently this package includes a heavily revised
    copy of the citeproc-hs code. When citeproc-hs is
    updated to be compatible, this package will simply
    depend on citeproc-hs.
    .
    This package also contains an executable: pandoc-citeproc,
    which works as a pandoc filter, and
    also has a mode for converting bibliographic databases
    a YAML format suitable for inclusion in pandoc YAML
    metadata.
category: Text
author: John MacFarlane, Andrea Rossato
exposed: True
indefinite: False
exposed-modules:
    Text.CSL Text.CSL.Data Text.CSL.Eval Text.CSL.Eval.Common
    Text.CSL.Eval.Date Text.CSL.Eval.Names Text.CSL.Eval.Output
    Text.CSL.Exception Text.CSL.Input.Bibtex Text.CSL.Input.Bibutils
    Text.CSL.Output.Pandoc Text.CSL.Output.Plain Text.CSL.Pandoc
    Text.CSL.Parser Text.CSL.Proc Text.CSL.Proc.Collapse
    Text.CSL.Proc.Disamb Text.CSL.Reference Text.CSL.Style
hidden-modules: Text.CSL.Util Prelude Paths_pandoc_citeproc
                Text.CSL.Compat.Pandoc
abi: f8a934cc042fd648808ec9edd5985148
trusted: False
import-dirs: /usr/lib/ghc-8.2.1/site-local/pandoc-citeproc-0.11.1.3
library-dirs: /usr/lib/ghc-8.2.1/site-local/pandoc-citeproc-0.11.1.3
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/pandoc-citeproc
hs-libraries: HSpandoc-citeproc-0.11.1.3-ILikW0TUk5qIp9f2RvCVVS
depends:
    containers-0.5.10.2 directory-1.3.0.2
    mtl-2.2.1-19EL8AGBsN3DnnOhrC9xY3 bytestring-0.10.8.2
    filepath-1.4.1.2 pandoc-types-1.17.2-Fl8qYoEQbpODaVFN2ZWOXB
    pandoc-1.19.2.1-6LS3gm1xTuF2jxYP0d5ZMM
    tagsoup-0.14.1-Dd68OXPvIKPH8wN6EGE1ft
    aeson-1.2.3.0-SQQydLO5BXKh1lJDeeNrq
    text-1.2.2.2-KYRZgO9N4MoJ4sC5lMiKTz
    vector-0.12.0.1-CnPH69pDwM4A5esizlXfXi
    xml-conduit-1.6.0-62u0Ld0g8V2oBOe0ChvET
    unordered-containers-0.2.8.0-KL4HUdwCmhYBQDTvY5v0GN
    data-default-0.7.1.1-7D2kYbZAPZs3NL2w6K0r5J
    setenv-0.1.1.3-BDKZw88F6QnHLVIxtB3r29
    split-0.2.3.2-89BHvn20PlL73pGr1SBIHj
    yaml-0.8.24-2wdOOQKc6Dt63OCZo8Nf1H
    hs-bibutils-6.2.0.1-ewhJkVIVTX3sjVOz1mire
    text-icu-0.7.0.1-9QrjjiOgro6L8O3YDKMSJd base-4.10.0.0
    syb-0.7-2rRPTNxBP6YFePrCXw4i2o parsec-3.1.11-5WCVqUZr6ypLPXtYWYsMnh
    old-locale-1.0.0.7-1sqf81TERjR1yVX7sI2OtM time-1.8.0.2
abi-depends: containers-0.5.10.2=e51b78cedb073051e10b1c1314421145
             directory-1.3.0.2=cfeb01f7201df723a8082d0da3163aee
             mtl-2.2.1-19EL8AGBsN3DnnOhrC9xY3=14e57a3b735adfe06c357bcc64de3dbd
             bytestring-0.10.8.2=db54a9a10f4b3abcd860c80f928b2ae9
             filepath-1.4.1.2=2a8b7688454d81e83f77ef81b74e0636
             pandoc-types-1.17.2-Fl8qYoEQbpODaVFN2ZWOXB=671e07ddd80a4e21a2a78e76900b479f
             pandoc-1.19.2.1-6LS3gm1xTuF2jxYP0d5ZMM=ce6d7820dff3844a49d63f4cf00807c0
             tagsoup-0.14.1-Dd68OXPvIKPH8wN6EGE1ft=3fbcc782bd8302af2fafeef32df01fde
             aeson-1.2.3.0-SQQydLO5BXKh1lJDeeNrq=8b90ef7c46d906c8047345fb433e32fe
             text-1.2.2.2-KYRZgO9N4MoJ4sC5lMiKTz=b7786dac6fdbd4e62fbcd8f2e5703783
             vector-0.12.0.1-CnPH69pDwM4A5esizlXfXi=bde86a27d0899b74a82f3bf1fe9b817c
             xml-conduit-1.6.0-62u0Ld0g8V2oBOe0ChvET=2bccb95a7de00653c043eff4c949c174
             unordered-containers-0.2.8.0-KL4HUdwCmhYBQDTvY5v0GN=7d7e1f3460b904c0be93ffa55855f4d0
             data-default-0.7.1.1-7D2kYbZAPZs3NL2w6K0r5J=066f8e1a5e7dca2a5fd62aefb939793f
             setenv-0.1.1.3-BDKZw88F6QnHLVIxtB3r29=221ec96ab272bbe35b12c27562404c0e
             split-0.2.3.2-89BHvn20PlL73pGr1SBIHj=c51f43c3e91d41531ae5282d108271a0
             yaml-0.8.24-2wdOOQKc6Dt63OCZo8Nf1H=f3316d9da6e6607f19b5fc76111163c2
             hs-bibutils-6.2.0.1-ewhJkVIVTX3sjVOz1mire=570377d4477eb59b5515cb2456203830
             text-icu-0.7.0.1-9QrjjiOgro6L8O3YDKMSJd=d4faf84122c7c9176a18aa5a178bb9cf
             base-4.10.0.0=a43b4ec12ad02cbfcdfe91f0942afb0a
             syb-0.7-2rRPTNxBP6YFePrCXw4i2o=db83b83263dcafbe734df45ece7027fc
             parsec-3.1.11-5WCVqUZr6ypLPXtYWYsMnh=da03630454c215de5f3965e7b0f0e5da
             old-locale-1.0.0.7-1sqf81TERjR1yVX7sI2OtM=bb3d8fbe7de4d3cc9ed854226de736b7
             time-1.8.0.2=96b65c0ad01f633ba36ea5ef13a79f41
haddock-interfaces: /usr/share/doc/pandoc-citeproc/html/pandoc-citeproc.haddock
haddock-html: /usr/share/doc/pandoc-citeproc/html
' | '/usr/sbin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> pandoc-citeproc-0.11.1.3-2-i686.pkg.tar.xz: usr/share/haskell/register/pandoc-citeproc.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/sbin:/usr/bin:/sbin:/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: pandoc-citeproc
version: 0.11.1.3
id: pandoc-citeproc-0.11.1.3-2bONERnKITQ5sNHcGHmMgc
key: pandoc-citeproc-0.11.1.3-2bONERnKITQ5sNHcGHmMgc
license: BSD3
maintainer: jgm@berkeley.edu
homepage: https://github.com/jgm/pandoc-citeproc
synopsis: Supports using pandoc with citeproc
description:
    The pandoc-citeproc library exports functions for
    using the citeproc system with pandoc.  It relies on
    citeproc-hs, a library for rendering
    bibliographic reference citations into a variety
    of styles using a macro language called Citation
    Style Language (CSL). More details on CSL can be
    found here: <http://citationstyles.org/>.
    .
    Currently this package includes a heavily revised
    copy of the citeproc-hs code. When citeproc-hs is
    updated to be compatible, this package will simply
    depend on citeproc-hs.
    .
    This package also contains an executable: pandoc-citeproc,
    which works as a pandoc filter, and
    also has a mode for converting bibliographic databases
    a YAML format suitable for inclusion in pandoc YAML
    metadata.
category: Text
author: John MacFarlane, Andrea Rossato
exposed: True
indefinite: False
exposed-modules:
    Text.CSL Text.CSL.Data Text.CSL.Eval Text.CSL.Eval.Common
    Text.CSL.Eval.Date Text.CSL.Eval.Names Text.CSL.Eval.Output
    Text.CSL.Exception Text.CSL.Input.Bibtex Text.CSL.Input.Bibutils
    Text.CSL.Output.Pandoc Text.CSL.Output.Plain Text.CSL.Pandoc
    Text.CSL.Parser Text.CSL.Proc Text.CSL.Proc.Collapse
    Text.CSL.Proc.Disamb Text.CSL.Reference Text.CSL.Style
hidden-modules: Text.CSL.Util Prelude Paths_pandoc_citeproc
                Text.CSL.Compat.Pandoc
abi: e7e970501b191a59a555d688dd4851ae
trusted: False
import-dirs: /usr/lib/ghc-8.2.1/site-local/pandoc-citeproc-0.11.1.3
library-dirs: /usr/lib/ghc-8.2.1/site-local/pandoc-citeproc-0.11.1.3
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/pandoc-citeproc
hs-libraries: HSpandoc-citeproc-0.11.1.3-2bONERnKITQ5sNHcGHmMgc
depends:
    containers-0.5.10.2 directory-1.3.0.2
    mtl-2.2.1-19EL8AGBsN3DnnOhrC9xY3 bytestring-0.10.8.2
    filepath-1.4.1.2 pandoc-types-1.17.2-Fl8qYoEQbpODaVFN2ZWOXB
    pandoc-2.0.1-AiX4ntF98eeDK0mCLPGeG
    tagsoup-0.14.1-Dd68OXPvIKPH8wN6EGE1ft
    aeson-1.2.3.0-SQQydLO5BXKh1lJDeeNrq
    text-1.2.2.2-KYRZgO9N4MoJ4sC5lMiKTz
    vector-0.12.0.1-CnPH69pDwM4A5esizlXfXi
    xml-conduit-1.6.0-62u0Ld0g8V2oBOe0ChvET
    unordered-containers-0.2.8.0-KL4HUdwCmhYBQDTvY5v0GN
    data-default-0.7.1.1-7D2kYbZAPZs3NL2w6K0r5J
    setenv-0.1.1.3-BDKZw88F6QnHLVIxtB3r29
    split-0.2.3.2-89BHvn20PlL73pGr1SBIHj
    yaml-0.8.24-2wdOOQKc6Dt63OCZo8Nf1H
    hs-bibutils-6.2.0.1-ewhJkVIVTX3sjVOz1mire
    text-icu-0.7.0.1-9QrjjiOgro6L8O3YDKMSJd base-4.10.0.0
    syb-0.7-2rRPTNxBP6YFePrCXw4i2o parsec-3.1.11-5WCVqUZr6ypLPXtYWYsMnh
    old-locale-1.0.0.7-1sqf81TERjR1yVX7sI2OtM time-1.8.0.2
abi-depends: containers-0.5.10.2=e51b78cedb073051e10b1c1314421145
             directory-1.3.0.2=cfeb01f7201df723a8082d0da3163aee
             mtl-2.2.1-19EL8AGBsN3DnnOhrC9xY3=14e57a3b735adfe06c357bcc64de3dbd
             bytestring-0.10.8.2=db54a9a10f4b3abcd860c80f928b2ae9
             filepath-1.4.1.2=2a8b7688454d81e83f77ef81b74e0636
             pandoc-types-1.17.2-Fl8qYoEQbpODaVFN2ZWOXB=671e07ddd80a4e21a2a78e76900b479f
             pandoc-2.0.1-AiX4ntF98eeDK0mCLPGeG=8927a16822170c32283144895bb45ced
             tagsoup-0.14.1-Dd68OXPvIKPH8wN6EGE1ft=3fbcc782bd8302af2fafeef32df01fde
             aeson-1.2.3.0-SQQydLO5BXKh1lJDeeNrq=8b90ef7c46d906c8047345fb433e32fe
             text-1.2.2.2-KYRZgO9N4MoJ4sC5lMiKTz=b7786dac6fdbd4e62fbcd8f2e5703783
             vector-0.12.0.1-CnPH69pDwM4A5esizlXfXi=bde86a27d0899b74a82f3bf1fe9b817c
             xml-conduit-1.6.0-62u0Ld0g8V2oBOe0ChvET=2bccb95a7de00653c043eff4c949c174
             unordered-containers-0.2.8.0-KL4HUdwCmhYBQDTvY5v0GN=7d7e1f3460b904c0be93ffa55855f4d0
             data-default-0.7.1.1-7D2kYbZAPZs3NL2w6K0r5J=066f8e1a5e7dca2a5fd62aefb939793f
             setenv-0.1.1.3-BDKZw88F6QnHLVIxtB3r29=221ec96ab272bbe35b12c27562404c0e
             split-0.2.3.2-89BHvn20PlL73pGr1SBIHj=c51f43c3e91d41531ae5282d108271a0
             yaml-0.8.24-2wdOOQKc6Dt63OCZo8Nf1H=f3316d9da6e6607f19b5fc76111163c2
             hs-bibutils-6.2.0.1-ewhJkVIVTX3sjVOz1mire=570377d4477eb59b5515cb2456203830
             text-icu-0.7.0.1-9QrjjiOgro6L8O3YDKMSJd=d4faf84122c7c9176a18aa5a178bb9cf
             base-4.10.0.0=a43b4ec12ad02cbfcdfe91f0942afb0a
             syb-0.7-2rRPTNxBP6YFePrCXw4i2o=db83b83263dcafbe734df45ece7027fc
             parsec-3.1.11-5WCVqUZr6ypLPXtYWYsMnh=da03630454c215de5f3965e7b0f0e5da
             old-locale-1.0.0.7-1sqf81TERjR1yVX7sI2OtM=bb3d8fbe7de4d3cc9ed854226de736b7
             time-1.8.0.2=96b65c0ad01f633ba36ea5ef13a79f41
haddock-interfaces: /usr/share/doc/pandoc-citeproc/html/pandoc-citeproc.haddock
haddock-html: /usr/share/doc/pandoc-citeproc/html
' | '/usr/sbin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
